<!--

@license Apache-2.0

Copyright (c) 2024 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->


<details>
  <summary>
    About stdlib...
  </summary>
  <p>We believe in a future in which the web is a preferred environment for numerical computation. To help realize this future, we've built stdlib. stdlib is a standard library, with an emphasis on numerical and scientific computation, written in JavaScript (and C) for execution in browsers and in Node.js.</p>
  <p>The library is fully decomposable, being architected in such a way that you can swap out and mix and match APIs and functionality to cater to your exact preferences and use cases.</p>
  <p>When you use stdlib, you can be absolutely certain that you are using the most thorough, rigorous, well-written, studied, documented, tested, measured, and high-quality code out there.</p>
  <p>To join us in bringing numerical computing to the web, get started by checking us out on <a href="https://github.com/stdlib-js/stdlib">GitHub</a>, and please consider <a href="https://opencollective.com/stdlib">financially supporting stdlib</a>. We greatly appreciate your continued support!</p>
</details>

# Complex128

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Double-precision complex floating-point number functions.

<section class="installation">

## Installation

```bash
npm install @stdlib/complex-float64
```

</section>

<section class="usage">

## Usage

```javascript
var complex = require( '@stdlib/complex-float64' );
```

#### complex

Namespace containing double-precision complex floating-point number functions.

```javascript
var ns = complex;
// returns {...}
```

The namespace contains the following sub-namespaces:

<!-- <toc pattern="+(base)"> -->

<div class="namespace-toc">

-   <span class="signature">[`base`][@stdlib/complex/float64/base]</span><span class="delimiter">: </span><span class="description">base (i.e., lower-level) double-precision complex floating-point number functions.</span>

</div>

<!-- </toc> -->

The namespace contains the following functions:

<!-- <toc pattern="*"> -->

<div class="namespace-toc">

-   <span class="signature">[`conj( z )`][@stdlib/complex/float64/conj]</span><span class="delimiter">: </span><span class="description">return the complex conjugate of a double-precision complex floating-point number.</span>
-   <span class="signature">[`Complex128( real, imag )`][@stdlib/complex/float64/ctor]</span><span class="delimiter">: </span><span class="description">128-bit complex number.</span>
-   <span class="signature">[`imag( z )`][@stdlib/complex/float64/imag]</span><span class="delimiter">: </span><span class="description">return the imaginary component of a double-precision complex floating-point number.</span>
-   <span class="signature">[`parseComplex128( str )`][@stdlib/complex/float64/parse]</span><span class="delimiter">: </span><span class="description">parse a string representation of a 128-bit complex number.</span>
-   <span class="signature">[`real( z )`][@stdlib/complex/float64/real]</span><span class="delimiter">: </span><span class="description">return the real component of a double-precision complex floating-point number.</span>
-   <span class="signature">[`reim( z )`][@stdlib/complex/float64/reim]</span><span class="delimiter">: </span><span class="description">return the real and imaginary components of a double-precision complex floating-point number.</span>
-   <span class="signature">[`reviveComplex128( key, value )`][@stdlib/complex/float64/reviver]</span><span class="delimiter">: </span><span class="description">revive a JSON-serialized 128-bit complex number.</span>

</div>

<!-- </toc> -->

</section>

<!-- /.usage -->

<!-- Package notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<section class="examples">

## Examples

<!-- TODO: better examples -->

<!-- eslint no-undef: "error" -->

```javascript
var objectKeys = require( '@stdlib/utils-keys' );
var ns = require( '@stdlib/complex-float64' );

console.log( objectKeys( ns ) );
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2024. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/complex-float64.svg
[npm-url]: https://npmjs.org/package/@stdlib/complex-float64

[test-image]: https://github.com/stdlib-js/complex-float64/actions/workflows/test.yml/badge.svg?branch=v0.3.0
[test-url]: https://github.com/stdlib-js/complex-float64/actions/workflows/test.yml?query=branch:v0.3.0

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/complex-float64/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/complex-float64?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/complex-float64.svg
[dependencies-url]: https://david-dm.org/stdlib-js/complex-float64/main

-->

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://app.gitter.im/#/room/#stdlib-js_stdlib:gitter.im

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/complex-float64/tree/deno
[deno-readme]: https://github.com/stdlib-js/complex-float64/blob/deno/README.md
[umd-url]: https://github.com/stdlib-js/complex-float64/tree/umd
[umd-readme]: https://github.com/stdlib-js/complex-float64/blob/umd/README.md
[esm-url]: https://github.com/stdlib-js/complex-float64/tree/esm
[esm-readme]: https://github.com/stdlib-js/complex-float64/blob/esm/README.md
[branches-url]: https://github.com/stdlib-js/complex-float64/blob/main/branches.md

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/complex-float64/main/LICENSE

<!-- <toc-links> -->

[@stdlib/complex/float64/conj]: https://www.npmjs.com/package/@stdlib/complex-float64-conj

[@stdlib/complex/float64/ctor]: https://www.npmjs.com/package/@stdlib/complex-float64-ctor

[@stdlib/complex/float64/imag]: https://www.npmjs.com/package/@stdlib/complex-float64-imag

[@stdlib/complex/float64/parse]: https://www.npmjs.com/package/@stdlib/complex-float64-parse

[@stdlib/complex/float64/real]: https://www.npmjs.com/package/@stdlib/complex-float64-real

[@stdlib/complex/float64/reim]: https://www.npmjs.com/package/@stdlib/complex-float64-reim

[@stdlib/complex/float64/reviver]: https://www.npmjs.com/package/@stdlib/complex-float64-reviver

[@stdlib/complex/float64/base]: https://www.npmjs.com/package/@stdlib/complex-float64-base

<!-- </toc-links> -->

</section>

<!-- /.links -->
